Request

Trait Request 

pub trait Request {
    // Required methods
    fn method(&self) -> Method;
    fn path(&self) -> &'static str;
    fn parameters(&self) -> Vec<(String, String)>;

    // Provided methods
    fn sensitive_parameter_names(&self) -> &'static [&'static str] { ... }
    fn request_parts(&self) -> RequestParts { ... }
}
Defines the behavior required from a request participant in the endpoint workflow.

Required Methods

fn method(&self) -> Method

Describes the provider wire contract for this Gingr request.

fn path(&self) -> &'static str

Describes the provider wire contract for this Gingr request.

fn parameters(&self) -> Vec<(String, String)>

Describes the provider wire contract for this Gingr request.

Provided Methods

fn sensitive_parameter_names(&self) -> &'static [&'static str]

Describes the provider wire contract for this Gingr request.

fn request_parts(&self) -> RequestParts

Describes the provider wire contract for this Gingr request.

Implementors