pub trait Request {
// Required methods
fn method(&self) -> Method;
fn path(&self) -> &'static str;
fn parameters(&self) -> Vec<(String, String)>;
// Provided methods
fn sensitive_parameter_names(&self) -> &'static [&'static str] { ... }
fn request_parts(&self) -> RequestParts { ... }
}Expand description
Defines the behavior required from a request participant in the endpoint workflow.
Required Methods
Sourcefn parameters(&self) -> Vec<(String, String)>
fn parameters(&self) -> Vec<(String, String)>
Describes the provider wire contract for this Gingr request.
Provided Methods
Sourcefn sensitive_parameter_names(&self) -> &'static [&'static str]
fn sensitive_parameter_names(&self) -> &'static [&'static str]
Describes the provider wire contract for this Gingr request.
Sourcefn request_parts(&self) -> RequestParts
fn request_parts(&self) -> RequestParts
Describes the provider wire contract for this Gingr request.